/****************************************************************************
** Meta object code from reading C++ file 'kcalc.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kcalc-17.12.3/kcalc.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcalc.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KCalculator_t {
    QByteArrayData data[83];
    char stringdata0[1431];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KCalculator_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KCalculator_t qt_meta_stringdata_KCalculator = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KCalculator"
QT_MOC_LITERAL(1, 12, 11), // "switchShift"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 10), // "switchMode"
QT_MOC_LITERAL(4, 36, 15), // "ButtonModeFlags"
QT_MOC_LITERAL(5, 52, 16), // "switchShowAccels"
QT_MOC_LITERAL(6, 69, 17), // "changeButtonNames"
QT_MOC_LITERAL(7, 87, 14), // "updateSettings"
QT_MOC_LITERAL(8, 102, 9), // "setColors"
QT_MOC_LITERAL(9, 112, 8), // "setFonts"
QT_MOC_LITERAL(10, 121, 10), // "EnterEqual"
QT_MOC_LITERAL(11, 132, 12), // "showSettings"
QT_MOC_LITERAL(12, 145, 17), // "slotSetSimpleMode"
QT_MOC_LITERAL(13, 163, 18), // "slotSetScienceMode"
QT_MOC_LITERAL(14, 182, 20), // "slotSetStatisticMode"
QT_MOC_LITERAL(15, 203, 18), // "slotSetNumeralMode"
QT_MOC_LITERAL(16, 222, 17), // "slotConstantsShow"
QT_MOC_LITERAL(17, 240, 7), // "toggled"
QT_MOC_LITERAL(18, 248, 14), // "slotBitsetshow"
QT_MOC_LITERAL(19, 263, 17), // "slotAngleSelected"
QT_MOC_LITERAL(20, 281, 4), // "mode"
QT_MOC_LITERAL(21, 286, 16), // "slotBaseSelected"
QT_MOC_LITERAL(22, 303, 4), // "base"
QT_MOC_LITERAL(23, 308, 17), // "slotNumberclicked"
QT_MOC_LITERAL(24, 326, 14), // "number_clicked"
QT_MOC_LITERAL(25, 341, 13), // "slotEEclicked"
QT_MOC_LITERAL(26, 355, 16), // "slotShifttoggled"
QT_MOC_LITERAL(27, 372, 9), // "myboolean"
QT_MOC_LITERAL(28, 382, 20), // "slotMemRecallclicked"
QT_MOC_LITERAL(29, 403, 19), // "slotMemStoreclicked"
QT_MOC_LITERAL(30, 423, 14), // "slotSinclicked"
QT_MOC_LITERAL(31, 438, 20), // "slotPlusMinusclicked"
QT_MOC_LITERAL(32, 459, 23), // "slotMemPlusMinusclicked"
QT_MOC_LITERAL(33, 483, 14), // "slotCosclicked"
QT_MOC_LITERAL(34, 498, 15), // "slotReciclicked"
QT_MOC_LITERAL(35, 514, 14), // "slotTanclicked"
QT_MOC_LITERAL(36, 529, 20), // "slotFactorialclicked"
QT_MOC_LITERAL(37, 550, 14), // "slotLogclicked"
QT_MOC_LITERAL(38, 565, 17), // "slotSquareclicked"
QT_MOC_LITERAL(39, 583, 15), // "slotCubeclicked"
QT_MOC_LITERAL(40, 599, 13), // "slotLnclicked"
QT_MOC_LITERAL(41, 613, 16), // "slotPowerclicked"
QT_MOC_LITERAL(42, 630, 19), // "slotMemClearclicked"
QT_MOC_LITERAL(43, 650, 16), // "slotClearclicked"
QT_MOC_LITERAL(44, 667, 19), // "slotAllClearclicked"
QT_MOC_LITERAL(45, 687, 20), // "slotParenOpenclicked"
QT_MOC_LITERAL(46, 708, 21), // "slotParenCloseclicked"
QT_MOC_LITERAL(47, 730, 14), // "slotANDclicked"
QT_MOC_LITERAL(48, 745, 25), // "slotMultiplicationclicked"
QT_MOC_LITERAL(49, 771, 19), // "slotDivisionclicked"
QT_MOC_LITERAL(50, 791, 13), // "slotORclicked"
QT_MOC_LITERAL(51, 805, 14), // "slotXORclicked"
QT_MOC_LITERAL(52, 820, 15), // "slotPlusclicked"
QT_MOC_LITERAL(53, 836, 16), // "slotMinusclicked"
QT_MOC_LITERAL(54, 853, 20), // "slotLeftShiftclicked"
QT_MOC_LITERAL(55, 874, 21), // "slotRightShiftclicked"
QT_MOC_LITERAL(56, 896, 17), // "slotPeriodclicked"
QT_MOC_LITERAL(57, 914, 16), // "slotEqualclicked"
QT_MOC_LITERAL(58, 931, 18), // "slotPercentclicked"
QT_MOC_LITERAL(59, 950, 17), // "slotNegateclicked"
QT_MOC_LITERAL(60, 968, 14), // "slotModclicked"
QT_MOC_LITERAL(61, 983, 18), // "slotStatNumclicked"
QT_MOC_LITERAL(62, 1002, 19), // "slotStatMeanclicked"
QT_MOC_LITERAL(63, 1022, 21), // "slotStatStdDevclicked"
QT_MOC_LITERAL(64, 1044, 21), // "slotStatMedianclicked"
QT_MOC_LITERAL(65, 1066, 24), // "slotStatDataInputclicked"
QT_MOC_LITERAL(66, 1091, 24), // "slotStatClearDataclicked"
QT_MOC_LITERAL(67, 1116, 14), // "slotHyptoggled"
QT_MOC_LITERAL(68, 1131, 4), // "flag"
QT_MOC_LITERAL(69, 1136, 16), // "slotConstclicked"
QT_MOC_LITERAL(70, 1153, 20), // "slotBackspaceclicked"
QT_MOC_LITERAL(71, 1174, 21), // "slotConstantToDisplay"
QT_MOC_LITERAL(72, 1196, 16), // "science_constant"
QT_MOC_LITERAL(73, 1213, 12), // "const_chosen"
QT_MOC_LITERAL(74, 1226, 26), // "slotChooseScientificConst0"
QT_MOC_LITERAL(75, 1253, 26), // "slotChooseScientificConst1"
QT_MOC_LITERAL(76, 1280, 26), // "slotChooseScientificConst2"
QT_MOC_LITERAL(77, 1307, 26), // "slotChooseScientificConst3"
QT_MOC_LITERAL(78, 1334, 26), // "slotChooseScientificConst4"
QT_MOC_LITERAL(79, 1361, 26), // "slotChooseScientificConst5"
QT_MOC_LITERAL(80, 1388, 17), // "slotBitsetChanged"
QT_MOC_LITERAL(81, 1406, 16), // "slotUpdateBitset"
QT_MOC_LITERAL(82, 1423, 7) // "KNumber"

    },
    "KCalculator\0switchShift\0\0switchMode\0"
    "ButtonModeFlags\0switchShowAccels\0"
    "changeButtonNames\0updateSettings\0"
    "setColors\0setFonts\0EnterEqual\0"
    "showSettings\0slotSetSimpleMode\0"
    "slotSetScienceMode\0slotSetStatisticMode\0"
    "slotSetNumeralMode\0slotConstantsShow\0"
    "toggled\0slotBitsetshow\0slotAngleSelected\0"
    "mode\0slotBaseSelected\0base\0slotNumberclicked\0"
    "number_clicked\0slotEEclicked\0"
    "slotShifttoggled\0myboolean\0"
    "slotMemRecallclicked\0slotMemStoreclicked\0"
    "slotSinclicked\0slotPlusMinusclicked\0"
    "slotMemPlusMinusclicked\0slotCosclicked\0"
    "slotReciclicked\0slotTanclicked\0"
    "slotFactorialclicked\0slotLogclicked\0"
    "slotSquareclicked\0slotCubeclicked\0"
    "slotLnclicked\0slotPowerclicked\0"
    "slotMemClearclicked\0slotClearclicked\0"
    "slotAllClearclicked\0slotParenOpenclicked\0"
    "slotParenCloseclicked\0slotANDclicked\0"
    "slotMultiplicationclicked\0slotDivisionclicked\0"
    "slotORclicked\0slotXORclicked\0"
    "slotPlusclicked\0slotMinusclicked\0"
    "slotLeftShiftclicked\0slotRightShiftclicked\0"
    "slotPeriodclicked\0slotEqualclicked\0"
    "slotPercentclicked\0slotNegateclicked\0"
    "slotModclicked\0slotStatNumclicked\0"
    "slotStatMeanclicked\0slotStatStdDevclicked\0"
    "slotStatMedianclicked\0slotStatDataInputclicked\0"
    "slotStatClearDataclicked\0slotHyptoggled\0"
    "flag\0slotConstclicked\0slotBackspaceclicked\0"
    "slotConstantToDisplay\0science_constant\0"
    "const_chosen\0slotChooseScientificConst0\0"
    "slotChooseScientificConst1\0"
    "slotChooseScientificConst2\0"
    "slotChooseScientificConst3\0"
    "slotChooseScientificConst4\0"
    "slotChooseScientificConst5\0slotBitsetChanged\0"
    "slotUpdateBitset\0KNumber"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KCalculator[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      71,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  369,    2, 0x06 /* Public */,
       3,    2,  372,    2, 0x06 /* Public */,
       5,    1,  377,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,  380,    2, 0x09 /* Protected */,
       7,    0,  381,    2, 0x09 /* Protected */,
       8,    0,  382,    2, 0x09 /* Protected */,
       9,    0,  383,    2, 0x09 /* Protected */,
      10,    0,  384,    2, 0x09 /* Protected */,
      11,    0,  385,    2, 0x09 /* Protected */,
      12,    0,  386,    2, 0x09 /* Protected */,
      13,    0,  387,    2, 0x09 /* Protected */,
      14,    0,  388,    2, 0x09 /* Protected */,
      15,    0,  389,    2, 0x09 /* Protected */,
      16,    1,  390,    2, 0x09 /* Protected */,
      18,    1,  393,    2, 0x09 /* Protected */,
      19,    1,  396,    2, 0x09 /* Protected */,
      21,    1,  399,    2, 0x09 /* Protected */,
      23,    1,  402,    2, 0x09 /* Protected */,
      25,    0,  405,    2, 0x09 /* Protected */,
      26,    1,  406,    2, 0x09 /* Protected */,
      28,    0,  409,    2, 0x09 /* Protected */,
      29,    0,  410,    2, 0x09 /* Protected */,
      30,    0,  411,    2, 0x09 /* Protected */,
      31,    0,  412,    2, 0x09 /* Protected */,
      32,    0,  413,    2, 0x09 /* Protected */,
      33,    0,  414,    2, 0x09 /* Protected */,
      34,    0,  415,    2, 0x09 /* Protected */,
      35,    0,  416,    2, 0x09 /* Protected */,
      36,    0,  417,    2, 0x09 /* Protected */,
      37,    0,  418,    2, 0x09 /* Protected */,
      38,    0,  419,    2, 0x09 /* Protected */,
      39,    0,  420,    2, 0x09 /* Protected */,
      40,    0,  421,    2, 0x09 /* Protected */,
      41,    0,  422,    2, 0x09 /* Protected */,
      42,    0,  423,    2, 0x09 /* Protected */,
      43,    0,  424,    2, 0x09 /* Protected */,
      44,    0,  425,    2, 0x09 /* Protected */,
      45,    0,  426,    2, 0x09 /* Protected */,
      46,    0,  427,    2, 0x09 /* Protected */,
      47,    0,  428,    2, 0x09 /* Protected */,
      48,    0,  429,    2, 0x09 /* Protected */,
      49,    0,  430,    2, 0x09 /* Protected */,
      50,    0,  431,    2, 0x09 /* Protected */,
      51,    0,  432,    2, 0x09 /* Protected */,
      52,    0,  433,    2, 0x09 /* Protected */,
      53,    0,  434,    2, 0x09 /* Protected */,
      54,    0,  435,    2, 0x09 /* Protected */,
      55,    0,  436,    2, 0x09 /* Protected */,
      56,    0,  437,    2, 0x09 /* Protected */,
      57,    0,  438,    2, 0x09 /* Protected */,
      58,    0,  439,    2, 0x09 /* Protected */,
      59,    0,  440,    2, 0x09 /* Protected */,
      60,    0,  441,    2, 0x09 /* Protected */,
      61,    0,  442,    2, 0x09 /* Protected */,
      62,    0,  443,    2, 0x09 /* Protected */,
      63,    0,  444,    2, 0x09 /* Protected */,
      64,    0,  445,    2, 0x09 /* Protected */,
      65,    0,  446,    2, 0x09 /* Protected */,
      66,    0,  447,    2, 0x09 /* Protected */,
      67,    1,  448,    2, 0x09 /* Protected */,
      69,    1,  451,    2, 0x09 /* Protected */,
      70,    0,  454,    2, 0x09 /* Protected */,
      71,    1,  455,    2, 0x09 /* Protected */,
      74,    1,  458,    2, 0x09 /* Protected */,
      75,    1,  461,    2, 0x09 /* Protected */,
      76,    1,  464,    2, 0x09 /* Protected */,
      77,    1,  467,    2, 0x09 /* Protected */,
      78,    1,  470,    2, 0x09 /* Protected */,
      79,    1,  473,    2, 0x09 /* Protected */,
      80,    1,  476,    2, 0x09 /* Protected */,
      81,    1,  479,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Bool,    2,    2,
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void, QMetaType::Int,   20,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void, QMetaType::Int,   24,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   27,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   68,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 72,   73,
    QMetaType::Void, 0x80000000 | 72,    2,
    QMetaType::Void, 0x80000000 | 72,    2,
    QMetaType::Void, 0x80000000 | 72,    2,
    QMetaType::Void, 0x80000000 | 72,    2,
    QMetaType::Void, 0x80000000 | 72,    2,
    QMetaType::Void, 0x80000000 | 72,    2,
    QMetaType::Void, QMetaType::ULongLong,    2,
    QMetaType::Void, 0x80000000 | 82,    2,

       0        // eod
};

void KCalculator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KCalculator *_t = static_cast<KCalculator *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->switchShift((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->switchMode((*reinterpret_cast< ButtonModeFlags(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 2: _t->switchShowAccels((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->changeButtonNames(); break;
        case 4: _t->updateSettings(); break;
        case 5: _t->setColors(); break;
        case 6: _t->setFonts(); break;
        case 7: _t->EnterEqual(); break;
        case 8: _t->showSettings(); break;
        case 9: _t->slotSetSimpleMode(); break;
        case 10: _t->slotSetScienceMode(); break;
        case 11: _t->slotSetStatisticMode(); break;
        case 12: _t->slotSetNumeralMode(); break;
        case 13: _t->slotConstantsShow((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->slotBitsetshow((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->slotAngleSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->slotBaseSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->slotNumberclicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->slotEEclicked(); break;
        case 19: _t->slotShifttoggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->slotMemRecallclicked(); break;
        case 21: _t->slotMemStoreclicked(); break;
        case 22: _t->slotSinclicked(); break;
        case 23: _t->slotPlusMinusclicked(); break;
        case 24: _t->slotMemPlusMinusclicked(); break;
        case 25: _t->slotCosclicked(); break;
        case 26: _t->slotReciclicked(); break;
        case 27: _t->slotTanclicked(); break;
        case 28: _t->slotFactorialclicked(); break;
        case 29: _t->slotLogclicked(); break;
        case 30: _t->slotSquareclicked(); break;
        case 31: _t->slotCubeclicked(); break;
        case 32: _t->slotLnclicked(); break;
        case 33: _t->slotPowerclicked(); break;
        case 34: _t->slotMemClearclicked(); break;
        case 35: _t->slotClearclicked(); break;
        case 36: _t->slotAllClearclicked(); break;
        case 37: _t->slotParenOpenclicked(); break;
        case 38: _t->slotParenCloseclicked(); break;
        case 39: _t->slotANDclicked(); break;
        case 40: _t->slotMultiplicationclicked(); break;
        case 41: _t->slotDivisionclicked(); break;
        case 42: _t->slotORclicked(); break;
        case 43: _t->slotXORclicked(); break;
        case 44: _t->slotPlusclicked(); break;
        case 45: _t->slotMinusclicked(); break;
        case 46: _t->slotLeftShiftclicked(); break;
        case 47: _t->slotRightShiftclicked(); break;
        case 48: _t->slotPeriodclicked(); break;
        case 49: _t->slotEqualclicked(); break;
        case 50: _t->slotPercentclicked(); break;
        case 51: _t->slotNegateclicked(); break;
        case 52: _t->slotModclicked(); break;
        case 53: _t->slotStatNumclicked(); break;
        case 54: _t->slotStatMeanclicked(); break;
        case 55: _t->slotStatStdDevclicked(); break;
        case 56: _t->slotStatMedianclicked(); break;
        case 57: _t->slotStatDataInputclicked(); break;
        case 58: _t->slotStatClearDataclicked(); break;
        case 59: _t->slotHyptoggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 60: _t->slotConstclicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 61: _t->slotBackspaceclicked(); break;
        case 62: _t->slotConstantToDisplay((*reinterpret_cast< const science_constant(*)>(_a[1]))); break;
        case 63: _t->slotChooseScientificConst0((*reinterpret_cast< const science_constant(*)>(_a[1]))); break;
        case 64: _t->slotChooseScientificConst1((*reinterpret_cast< const science_constant(*)>(_a[1]))); break;
        case 65: _t->slotChooseScientificConst2((*reinterpret_cast< const science_constant(*)>(_a[1]))); break;
        case 66: _t->slotChooseScientificConst3((*reinterpret_cast< const science_constant(*)>(_a[1]))); break;
        case 67: _t->slotChooseScientificConst4((*reinterpret_cast< const science_constant(*)>(_a[1]))); break;
        case 68: _t->slotChooseScientificConst5((*reinterpret_cast< const science_constant(*)>(_a[1]))); break;
        case 69: _t->slotBitsetChanged((*reinterpret_cast< quint64(*)>(_a[1]))); break;
        case 70: _t->slotUpdateBitset((*reinterpret_cast< const KNumber(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KCalculator::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KCalculator::switchShift)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KCalculator::*_t)(ButtonModeFlags , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KCalculator::switchMode)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KCalculator::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KCalculator::switchShowAccels)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KCalculator::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KCalculator.data,
      qt_meta_data_KCalculator,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KCalculator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCalculator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KCalculator.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KCalculator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 71)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 71;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 71)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 71;
    }
    return _id;
}

// SIGNAL 0
void KCalculator::switchShift(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KCalculator::switchMode(ButtonModeFlags _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KCalculator::switchShowAccels(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
