#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'colors.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORS_H
#define UI_COLORS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_Colors
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *displayColorsBox;
    QHBoxLayout *hboxLayout;
    QGridLayout *gridLayout;
    QLabel *textLabel1;
    KColorButton *kcfg_ForeColor;
    QLabel *textLabel2;
    KColorButton *kcfg_BackColor;
    QSpacerItem *spacerItem;
    QGroupBox *buttonColorsBox;
    QHBoxLayout *hboxLayout1;
    QGridLayout *gridLayout1;
    QLabel *textLabel3;
    KColorButton *kcfg_FunctionButtonsColor;
    QLabel *textLabel4;
    KColorButton *kcfg_StatButtonsColor;
    QLabel *textLabel5;
    KColorButton *kcfg_HexButtonsColor;
    QLabel *textLabel6;
    KColorButton *kcfg_NumberButtonsColor;
    QLabel *textLabel7;
    KColorButton *kcfg_MemoryButtonsColor;
    QLabel *textLabel8;
    KColorButton *kcfg_OperationButtonsColor;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *Colors)
    {
        if (Colors->objectName().isEmpty())
            Colors->setObjectName(QStringLiteral("Colors"));
        Colors->resize(240, 344);
        vboxLayout = new QVBoxLayout(Colors);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        displayColorsBox = new QGroupBox(Colors);
        displayColorsBox->setObjectName(QStringLiteral("displayColorsBox"));
        hboxLayout = new QHBoxLayout(displayColorsBox);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        textLabel1 = new QLabel(displayColorsBox);
        textLabel1->setObjectName(QStringLiteral("textLabel1"));
        textLabel1->setWordWrap(false);

        gridLayout->addWidget(textLabel1, 0, 0, 1, 1);

        kcfg_ForeColor = new KColorButton(displayColorsBox);
        kcfg_ForeColor->setObjectName(QStringLiteral("kcfg_ForeColor"));
        kcfg_ForeColor->setColor(QColor(0, 0, 0));

        gridLayout->addWidget(kcfg_ForeColor, 0, 1, 1, 1);

        textLabel2 = new QLabel(displayColorsBox);
        textLabel2->setObjectName(QStringLiteral("textLabel2"));
        textLabel2->setWordWrap(false);

        gridLayout->addWidget(textLabel2, 1, 0, 1, 1);

        kcfg_BackColor = new KColorButton(displayColorsBox);
        kcfg_BackColor->setObjectName(QStringLiteral("kcfg_BackColor"));
        kcfg_BackColor->setColor(QColor(189, 255, 180));

        gridLayout->addWidget(kcfg_BackColor, 1, 1, 1, 1);


        hboxLayout->addLayout(gridLayout);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addWidget(displayColorsBox);

        buttonColorsBox = new QGroupBox(Colors);
        buttonColorsBox->setObjectName(QStringLiteral("buttonColorsBox"));
        hboxLayout1 = new QHBoxLayout(buttonColorsBox);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        textLabel3 = new QLabel(buttonColorsBox);
        textLabel3->setObjectName(QStringLiteral("textLabel3"));
        textLabel3->setWordWrap(false);

        gridLayout1->addWidget(textLabel3, 0, 0, 1, 1);

        kcfg_FunctionButtonsColor = new KColorButton(buttonColorsBox);
        kcfg_FunctionButtonsColor->setObjectName(QStringLiteral("kcfg_FunctionButtonsColor"));

        gridLayout1->addWidget(kcfg_FunctionButtonsColor, 0, 1, 1, 1);

        textLabel4 = new QLabel(buttonColorsBox);
        textLabel4->setObjectName(QStringLiteral("textLabel4"));
        textLabel4->setWordWrap(false);

        gridLayout1->addWidget(textLabel4, 1, 0, 1, 1);

        kcfg_StatButtonsColor = new KColorButton(buttonColorsBox);
        kcfg_StatButtonsColor->setObjectName(QStringLiteral("kcfg_StatButtonsColor"));

        gridLayout1->addWidget(kcfg_StatButtonsColor, 1, 1, 1, 1);

        textLabel5 = new QLabel(buttonColorsBox);
        textLabel5->setObjectName(QStringLiteral("textLabel5"));
        textLabel5->setWordWrap(false);

        gridLayout1->addWidget(textLabel5, 2, 0, 1, 1);

        kcfg_HexButtonsColor = new KColorButton(buttonColorsBox);
        kcfg_HexButtonsColor->setObjectName(QStringLiteral("kcfg_HexButtonsColor"));

        gridLayout1->addWidget(kcfg_HexButtonsColor, 2, 1, 1, 1);

        textLabel6 = new QLabel(buttonColorsBox);
        textLabel6->setObjectName(QStringLiteral("textLabel6"));
        textLabel6->setWordWrap(false);

        gridLayout1->addWidget(textLabel6, 3, 0, 1, 1);

        kcfg_NumberButtonsColor = new KColorButton(buttonColorsBox);
        kcfg_NumberButtonsColor->setObjectName(QStringLiteral("kcfg_NumberButtonsColor"));

        gridLayout1->addWidget(kcfg_NumberButtonsColor, 3, 1, 1, 1);

        textLabel7 = new QLabel(buttonColorsBox);
        textLabel7->setObjectName(QStringLiteral("textLabel7"));
        textLabel7->setWordWrap(false);

        gridLayout1->addWidget(textLabel7, 4, 0, 1, 1);

        kcfg_MemoryButtonsColor = new KColorButton(buttonColorsBox);
        kcfg_MemoryButtonsColor->setObjectName(QStringLiteral("kcfg_MemoryButtonsColor"));

        gridLayout1->addWidget(kcfg_MemoryButtonsColor, 4, 1, 1, 1);

        textLabel8 = new QLabel(buttonColorsBox);
        textLabel8->setObjectName(QStringLiteral("textLabel8"));
        textLabel8->setWordWrap(false);

        gridLayout1->addWidget(textLabel8, 5, 0, 1, 1);

        kcfg_OperationButtonsColor = new KColorButton(buttonColorsBox);
        kcfg_OperationButtonsColor->setObjectName(QStringLiteral("kcfg_OperationButtonsColor"));

        gridLayout1->addWidget(kcfg_OperationButtonsColor, 5, 1, 1, 1);


        hboxLayout1->addLayout(gridLayout1);

        spacerItem1 = new QSpacerItem(31, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem1);


        vboxLayout->addWidget(buttonColorsBox);

        spacerItem2 = new QSpacerItem(151, 70, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem2);

#ifndef UI_QT_NO_SHORTCUT
        textLabel1->setBuddy(kcfg_ForeColor);
        textLabel2->setBuddy(kcfg_BackColor);
        textLabel3->setBuddy(kcfg_FunctionButtonsColor);
        textLabel4->setBuddy(kcfg_StatButtonsColor);
        textLabel5->setBuddy(kcfg_HexButtonsColor);
        textLabel6->setBuddy(kcfg_NumberButtonsColor);
        textLabel7->setBuddy(kcfg_MemoryButtonsColor);
        textLabel8->setBuddy(kcfg_OperationButtonsColor);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(kcfg_ForeColor, kcfg_BackColor);
        QWidget::setTabOrder(kcfg_BackColor, kcfg_FunctionButtonsColor);
        QWidget::setTabOrder(kcfg_FunctionButtonsColor, kcfg_StatButtonsColor);
        QWidget::setTabOrder(kcfg_StatButtonsColor, kcfg_HexButtonsColor);
        QWidget::setTabOrder(kcfg_HexButtonsColor, kcfg_NumberButtonsColor);
        QWidget::setTabOrder(kcfg_NumberButtonsColor, kcfg_MemoryButtonsColor);
        QWidget::setTabOrder(kcfg_MemoryButtonsColor, kcfg_OperationButtonsColor);

        retranslateUi(Colors);

        QMetaObject::connectSlotsByName(Colors);
    } // setupUi

    void retranslateUi(QWidget *Colors)
    {
        displayColorsBox->setTitle(tr2i18n("Display Colors", Q_NULLPTR));
        textLabel1->setText(tr2i18n("&Foreground:", Q_NULLPTR));
        kcfg_ForeColor->setText(QString());
        textLabel2->setText(tr2i18n("&Background:", Q_NULLPTR));
        kcfg_BackColor->setText(QString());
        buttonColorsBox->setTitle(tr2i18n("Button Colors", Q_NULLPTR));
        textLabel3->setText(tr2i18n("&Functions:", Q_NULLPTR));
        kcfg_FunctionButtonsColor->setText(QString());
        textLabel4->setText(tr2i18n("St&atistic functions:", Q_NULLPTR));
        kcfg_StatButtonsColor->setText(QString());
        textLabel5->setText(tr2i18n("He&xadecimals:", Q_NULLPTR));
        kcfg_HexButtonsColor->setText(QString());
        textLabel6->setText(tr2i18n("&Numbers:", Q_NULLPTR));
        kcfg_NumberButtonsColor->setText(QString());
        textLabel7->setText(tr2i18n("&Memory:", Q_NULLPTR));
        kcfg_MemoryButtonsColor->setText(QString());
        textLabel8->setText(tr2i18n("O&perations:", Q_NULLPTR));
        kcfg_OperationButtonsColor->setText(QString());
        Q_UNUSED(Colors);
    } // retranslateUi

};

namespace Ui {
    class Colors: public Ui_Colors {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLORS_H

