/****************************************************************************
** Meta object code from reading C++ file 'kcalcdisplay.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kcalc-17.12.3/kcalcdisplay.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcalcdisplay.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KCalcDisplay_t {
    QByteArrayData data[14];
    char stringdata0[171];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KCalcDisplay_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KCalcDisplay_t qt_meta_stringdata_KCalcDisplay = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KCalcDisplay"
QT_MOC_LITERAL(1, 13, 7), // "clicked"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 11), // "changedText"
QT_MOC_LITERAL(4, 34, 13), // "changedAmount"
QT_MOC_LITERAL(5, 48, 7), // "KNumber"
QT_MOC_LITERAL(6, 56, 7), // "slotCut"
QT_MOC_LITERAL(7, 64, 8), // "slotCopy"
QT_MOC_LITERAL(8, 73, 9), // "slotPaste"
QT_MOC_LITERAL(9, 83, 10), // "bClipboard"
QT_MOC_LITERAL(10, 94, 21), // "slotSelectionTimedOut"
QT_MOC_LITERAL(11, 116, 19), // "slotDisplaySelected"
QT_MOC_LITERAL(12, 136, 15), // "slotHistoryBack"
QT_MOC_LITERAL(13, 152, 18) // "slotHistoryForward"

    },
    "KCalcDisplay\0clicked\0\0changedText\0"
    "changedAmount\0KNumber\0slotCut\0slotCopy\0"
    "slotPaste\0bClipboard\0slotSelectionTimedOut\0"
    "slotDisplaySelected\0slotHistoryBack\0"
    "slotHistoryForward"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KCalcDisplay[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,
       3,    1,   70,    2, 0x06 /* Public */,
       4,    1,   73,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,   76,    2, 0x0a /* Public */,
       7,    0,   77,    2, 0x0a /* Public */,
       8,    1,   78,    2, 0x0a /* Public */,
       8,    0,   81,    2, 0x2a /* Public | MethodCloned */,
      10,    0,   82,    2, 0x08 /* Private */,
      11,    0,   83,    2, 0x08 /* Private */,
      12,    0,   84,    2, 0x08 /* Private */,
      13,    0,   85,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 5,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KCalcDisplay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KCalcDisplay *_t = static_cast<KCalcDisplay *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->clicked(); break;
        case 1: _t->changedText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->changedAmount((*reinterpret_cast< const KNumber(*)>(_a[1]))); break;
        case 3: _t->slotCut(); break;
        case 4: _t->slotCopy(); break;
        case 5: _t->slotPaste((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->slotPaste(); break;
        case 7: _t->slotSelectionTimedOut(); break;
        case 8: _t->slotDisplaySelected(); break;
        case 9: _t->slotHistoryBack(); break;
        case 10: _t->slotHistoryForward(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KCalcDisplay::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KCalcDisplay::clicked)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KCalcDisplay::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KCalcDisplay::changedText)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KCalcDisplay::*_t)(const KNumber & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KCalcDisplay::changedAmount)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KCalcDisplay::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_KCalcDisplay.data,
      qt_meta_data_KCalcDisplay,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KCalcDisplay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCalcDisplay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KCalcDisplay.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int KCalcDisplay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KCalcDisplay::clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KCalcDisplay::changedText(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KCalcDisplay::changedAmount(const KNumber & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
