/****************************************************************************
** Meta object code from reading C++ file 'kcalc_const_button.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kcalc-17.12.3/kcalc_const_button.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcalc_const_button.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KCalcConstButton_t {
    QByteArrayData data[9];
    char stringdata0[118];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KCalcConstButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KCalcConstButton_t qt_meta_stringdata_KCalcConstButton = {
    {
QT_MOC_LITERAL(0, 0, 16), // "KCalcConstButton"
QT_MOC_LITERAL(1, 17, 7), // "clicked"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 3), // "num"
QT_MOC_LITERAL(4, 30, 19), // "slotConfigureButton"
QT_MOC_LITERAL(5, 50, 25), // "slotChooseScientificConst"
QT_MOC_LITERAL(6, 76, 16), // "science_constant"
QT_MOC_LITERAL(7, 93, 12), // "const_chosen"
QT_MOC_LITERAL(8, 106, 11) // "slotClicked"

    },
    "KCalcConstButton\0clicked\0\0num\0"
    "slotConfigureButton\0slotChooseScientificConst\0"
    "science_constant\0const_chosen\0slotClicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KCalcConstButton[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   37,    2, 0x08 /* Private */,
       5,    1,   38,    2, 0x08 /* Private */,
       8,    0,   41,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,

       0        // eod
};

void KCalcConstButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KCalcConstButton *_t = static_cast<KCalcConstButton *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->slotConfigureButton(); break;
        case 2: _t->slotChooseScientificConst((*reinterpret_cast< const science_constant(*)>(_a[1]))); break;
        case 3: _t->slotClicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KCalcConstButton::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KCalcConstButton::clicked)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KCalcConstButton::staticMetaObject = {
    { &KCalcButton::staticMetaObject, qt_meta_stringdata_KCalcConstButton.data,
      qt_meta_data_KCalcConstButton,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KCalcConstButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCalcConstButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KCalcConstButton.stringdata0))
        return static_cast<void*>(this);
    return KCalcButton::qt_metacast(_clname);
}

int KCalcConstButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCalcButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KCalcConstButton::clicked(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
